@@ -265,8 +265,7 @@ class TickerDax:
                     uri,
                     extra_headers={'email': self._email, 'token': self._websocket_api_key}
             ) as connected_socket:
-                now = datetime.now(tz=timezone.utc).strftime('%Y-%m-%dT%H:%M:%S')
-                self._logger.info(f' [{now}] > Connected to {uri}')
+                self._logger.info(f'> Connected to {uri}')
                 while True:
                     data = json.loads(await connected_socket.recv())
                     symbol = data.get('symbol')
@@ -286,7 +285,7 @@ class TickerDax:
             if error.status_code == 401:
                 self.report_error(
                     'This email and API key combination are not authorized to connect to '
-                    'the https://tickerdax.com websocket API. Please check you credentials.'
+                    f'the {self._host} websocket API. Please check your credentials.'
                 )
 
     async def _rest_request(self, route, symbol, timestamps):
@@ -361,7 +360,9 @@ class TickerDax:
         for cached_value in self.cached_values:
             symbol = cached_value.get('symbol')
             timestamp = cached_value.get('id')
-            keys.remove(f'{NAME}/{route}/{symbol}/{timestamp}')
+            key = f'{NAME}/{route}/{symbol}/{timestamp}'
+            if key in keys:
+                keys.remove(key)
         result.extend(self.cached_values)
 
         # cache the rest values
@@ -371,8 +372,9 @@ class TickerDax:
             key = f'{NAME}/{route}/{symbol}/{timestamp}'
 
             self._redis_client.set(key, json.dumps(rest_value))
-            # remove all the cache keys now  that it is cached
-            keys.remove(key)
+            # remove the key now that it is cached
+            if key in keys:
+                keys.remove(key)
         result.extend(self.rest_values)
 
         # if there are any remaining keys, then that means they were missing from the rest api
