@@ -1,12 +1,11 @@
 from tickerdax.constants import KeyTypes
 from tickerdax.config_base import ConfigBase
-from tickerdax.client import TickerDax
 from tickerdax.downloader import Downloader
 
 
 class Streamer(ConfigBase):
     """
-    Streams data from the https://tickerdax.com websocket api to the cache using a provided config.
+    Streams data from the tickerdax.com websocket api to the cache using a provided config.
     """
     def __init__(self, config, client_kwargs=None):
         super(Streamer, self).__init__(config, client_kwargs)
